#!/usr/local/bin/python3

#################################################
#                                               #
# SuperPlayer Bluetooth (BLE) remote controller #
#                                               #
# Build with help from different sources (www)  #
#                                               #
# Jesper Lykke [user :: Lykkedk @ diyaudio.com] #
#                                               #
#################################################

from camilladsp import CamillaConnection
import io
import os
import stat
import subprocess
import sys
from subprocess import call
import time
from bluepy.btle import UUID, Peripheral

# Pass the MAC adress on cmdline. If missing then pass value
# "B8:F0:09:CD:30:F2" <--- The MAC adress of the 'cheap' ESP32
# "FC:F5:C4:06:BB:C6" <--- The MAC adress of the ESP32 Feather (battery powered)
MyESP=sys.argv[1] if len(sys.argv) > 1 else "FC:F5:C4:06:BB:C6" # <--- ESP32 Feather

cdsp = CamillaConnection("127.0.0.1", 1234)

Battfile = "/home/tc/battery.txt" # Location of battery -level (VDC) file
uid = 1001                        # 1001 = tc
gid = 50                          # 50 = staff

GO = int(1)            # Go through loop = (1)
MUTE = int(0)          # Mute = (1) / Unmute = (0)

# CamillaDSP '--gain <gain>': Must be a number between -120 and +20

volume = int(-0)       # We start with volume at -0dB
MIN_volume = int(-110) # Lower limit with some proof
MAX_volume = int(-0)   # Upper limit without 'clipping'
CN = int(-0)           # Set volume default for Unmute / Mute

value = (0x002a)                               # BLE Characteristic
p = Peripheral(MyESP, "public")
OLD_value = p.readCharacteristic(value)        # The first readen value
LONG_press = b'\xa8a\x00\x00'                  # = 25000 from Arduino/ESP32 Serial monitor
DOUBLE_press = b'P\xc3\x00\x00'                # = 50000 from Arduino/ESP32 Serial monitor

while 1:

    if (GO == 1):
        raw = p.readCharacteristic(value)

        Batt = int.from_bytes(raw, byteorder='little')
        if (Batt > 2000 and Batt < 5000):
            Batt = (Batt / 1000)
            Batt = round(Batt, 1)
            print ("Battery VDC : +",Batt)
            Batt = str(Batt)
            with open(Battfile, 'w') as Battery:
                Battery.write(Batt)

            os.chown(Battfile, uid, gid)
            time.sleep(0.50)

        if (MUTE == 0):
            if (raw < OLD_value):
                #call(["/usr/local/bin/pcp", "down"])
                volume = (volume -1.5)
                cdsp.connect()
                CN=cdsp.get_volume()
                if (CN <= MIN_volume):
                    volume = int(MIN_volume)
                    cdsp.connect()
                    cdsp.set_volume(volume)
                    CN=cdsp.get_volume()

                cdsp.connect()
                cdsp.set_volume(volume)
                CN=cdsp.get_volume()
                print ("Volume DOWN :", CN)
                OLD_value = raw

        if (MUTE == 0):
            if (raw > OLD_value):
                #call(["/usr/local/bin/pcp", "up"])
                volume = (volume +1.5)
                cdsp.connect()
                CN=cdsp.get_volume()
                if (CN >= MAX_volume):
                    volume = int(MAX_volume)
                    cdsp.connect()
                    cdsp.set_volume(volume)
                    CN=cdsp.get_volume()

                cdsp.connect()
                cdsp.set_volume(volume)
                CN=cdsp.get_volume()
                print ("Volume UP   :", CN)
                OLD_value = raw

        if (raw == LONG_press):
            call(["/usr/local/bin/pcp", "pause"])
            print ("Pause / Play")
            raw = OLD_value
            time.sleep(1.00)

        if (raw == DOUBLE_press):
            print ("Double press")
            MUTE = (MUTE + 1) % 2
            if (MUTE == 0):
                print ("<> Unmute system <>")
                cdsp.connect()
                cdsp.set_volume(CN)
                time.sleep(1.00)
            if (MUTE == 1):
                print ("<> Mute system <>")
                cdsp.connect()
                CN=cdsp.get_volume()
                cdsp.set_volume(MIN_volume)
                time.sleep(1.00)

time.sleep(0.05)
