#!/bin/sh

#################################################
#                                               #
# SuperPlayer Bluetooth (BLE) remote controller #
#                                               #
# Build with help from different sources (www)  #
#                                               #
# Jesper Lykke [user :: Lykkedk @ diyaudio.com] #
#                                               #
#################################################

SPD_SHELL="SuperPlayer-daemon.sh"

CMD=$1
ESP32_MAC=$2
ESP32_MANUFACTOR=$3
DEBUG=$4

# Future option [ DEBUG mode ]
if [ $DEBUG = "debug" ]; then
echo "Debug mode ON"
fi

BATTERY_FILE=/home/tc/battery.txt
BOOT_COUNT_FILE=/home/tc/bootcount.txt
SCANNER_FILE=/home/tc/scanner.txt
PY_DAEMON=/home/tc/SuperPlayer-Controller.py
PY_NAME=SuperPlayer-Controller.py

status () {
 echo "Status!"
 echo
 echo "$(ps aux | grep 'SuperPlayer-Controller.py')"
 echo
 echo "$(ps aux | grep 'SuperPlayer-daemon.sh start')"
 echo
 exit 1
 }

init_stop () {
  if [ -n "$(pgrep -f $PY_DAEMON)" ]; then
  echo "Stopping $PY_NAME..."
  kill $(pgrep -f $PY_DAEMON)
  exit 1
  else
  echo "$PY_NAME is not started"
  fi
  }

killme () {
  echo "KillMe!"
  if [ -n "$(pgrep -f $PY_DAEMON)" ]; then
  echo "Stopping $PY_NAME..."
  kill $(pgrep -f $PY_DAEMON)
  fi
  if [ -n "$(pgrep -f $SPD_SHELL)" ]; then
  echo "Stopping $SPD_SHELL..."
  kill $(pgrep -f $SPD_SHELL)
  fi
  }

init_start () {
  if [ -n "$(pgrep -f $PY_DAEMON)" ]; then
  echo "$PY_NAME is allready started "
  exit 1
  fi
  echo "Starting $PY_NAME"
  /usr/local/bin/python3 $PY_DAEMON $ESP32_MAC & # Pass MAC adress to python-script (SuperPlayer-Controller.py)
  }

check_scanner_file () {
  if [ ! -f $SCANNER_FILE ]; then
  echo "$SCANNER_FILE does NOT exist ---> I will create it now"
  touch $SCANNER_FILE
  chown tc:staff $SCANNER_FILE
  else
  echo "$SCANNER_FILE exist, ---> I will delete and create now"
  rm $SCANNER_FILE
  touch $SCANNER_FILE
  chown tc:staff $SCANNER_FILE
  fi
  }

check_battery_file () {
  if [ ! -f $BATTERY_FILE ]; then
  echo "$BATTERY_FILE does NOT exist ---> I will create it now"
  touch $BATTERY_FILE
  chown tc:staff $BATTERY_FILE
  else
  echo "$BATTERY_FILE exist, ---> I will delete and create now"
  rm $BATTERY_FILE
  touch $BATTERY_FILE
  chown tc:staff $BATTERY_FILE
  fi
  }

check_boot_count_file () {
  if [ ! -f $BOOT_COUNT_FILE ]; then
  echo "$BOOT_COUNT_FILE does NOT exist ---> I will create it now"
  touch $BOOT_COUNT_FILE
  chown tc:staff $BOOT_COUNT_FILE
  else
  echo "$BOOT_COUNT_FILE exist"
  rm $BOOT_COUNT_FILE
  touch $BOOT_COUNT_FILE
  chown tc:staff $BOOT_COUNT_FILE
  fi
  }

daemon_start () {
  echo "Starting $PY_NAME"
  /usr/local/bin/python3 $PY_DAEMON $ESP32_MAC & # Pass MAC adress to python-script (SuperPlayer-Controller.py)
  }

usage () {
  echo
  echo "SuperPlayer-daemon ::"
  echo
  echo "        SuperPlayer-daemon.sh start mac_adress manufactor : Start the PY-Daemon & This script with auto restart enabled"
  echo "(Debug) SuperPlayer-daemon.sh manuelstart                 : Start the PY-Daemon (only) with no auto restart"
  echo "(Debug) SuperPlayer-daemon.sh stop                        : Stop the PY-Daemon (only)"
  echo "        SuperPlayer-daemon.sh help                        : Show this help"
  echo "(Debug) SuperPlayer-daemon.sh killme                      : Kill's both PY-Daemon & this script"
  echo "(Debug) SuperPlayer-daemon.sh status                      : Show status of both PY_Daemon & this script"
  echo
  echo "[ Future option : Add debug to option will throw info, e.g. :: ]"
  echo "[ SuperPlayer-daemon start xx:xx:xx:xx:xx:xx RivieraWaves debug ]"
  echo
  echo "Example usage (normal start) ::"
  echo "SuperPlayer-daemon start xx:xx:xx:xx:xx:xx RivieraWaves"
  echo
  }

if [ $CMD = "manuelstart" ]; then
 init_start
 exit 1
fi

if [ $CMD = "stop" ]; then
 init_stop
 exit 1
fi

if [ $CMD = "help" ]; then
 usage
 exit 1
fi

if [ $CMD = "killme" ]; then
 killme
fi

if [ $CMD = "status" ]; then
 status
 exit 1
fi

check_boot_count_file # File to read ESP32 bootcount (Sleep / wakeup count)
check_scanner_file    # File to read Bluetooth BLE hci-tool find / status
check_battery_file    # File to read battery level from SuperPlayer-Controller.py script

if [ $CMD = "start" ]; then
  while :
  do
    if [ ! -n "$(pgrep -f $PY_DAEMON)" ]; then
    echo "$PY_NAME is not running"

      hcitool -i hci0 leinfo $ESP32_MAC > $SCANNER_FILE
      chown tc:staff $SCANNER_FILE

      if grep -q $ESP32_MANUFACTOR "$SCANNER_FILE"; then
      echo "$ESP32_MAC & $ESP32_MANUFACTOR is online"
      daemon_start

      BOOT_COUNT=$(cat $BOOT_COUNT_FILE)
      let BOOT_COUNT=$BOOT_COUNT+1
      echo $BOOT_COUNT > $BOOT_COUNT_FILE
      echo "Boot count = "$(cat $BOOT_COUNT_FILE)

      sleep 0.5
      else
      echo "$ESP32_MAC & $ESP32_MANUFACTOR is NOT online"
      sleep 2
      fi
    fi
  sleep 2
  done
fi

exit
